# -*- coding: utf-8 -*-

"""Test Logos

Utilisation :
    créer les variables d'environnement: (indiquer les valeurs
    pour le serveur ScoDoc que vous voulez interroger)

    export SCODOC_URL="https://scodoc.xxx.net/"
    export SCODOC_USER="xxx"
    export SCODOC_PASSWD="xxx"
    export CHECK_CERTIFICATE=0 # ou 1 si serveur de production avec certif SSL valide

    (on peut aussi placer ces valeurs dans un fichier .env du répertoire tests/api).

    Lancer :
        pytest tests/api/test_api_partitions.py
"""

import requests

from tests.api.setup_test_api import API_URL, CHECK_CERTIFICATE, api_headers
from tests.api.tools_test_api import verify_fields


def test_partition(api_headers):
    """
    Test 'partition'

    Route :
        - /partitions/<int:formsemestre_id>
    """
    fields = [
        "partition_id",
        "id",
        "formsemestre_id",
        "partition_name",
        "numero",
        "bul_show_rank",
        "show_in_lists",
    ]

    r = requests.get(
        API_URL + "/partitions/1",
        headers=api_headers,
        verify=CHECK_CERTIFICATE,
    )
    assert r.status_code == 200
    partitions = r.json()
    assert len(partitions) == 1
    partition = partitions[0]
    fields_ok = verify_fields(partition, fields)
    assert fields_ok is True


def test_etud_in_group(api_headers):
    """
    Test 'etud_in_group'

    Routes :
        - /partitions/groups/<int:group_id>
        - /partitions/groups/<int:group_id>/etat/<string:etat>
    """
    fields = [
        "etudid",
        "id",
        "dept_id",
        "nom",
        "prenom",
        "nom_usuel",
        "civilite",
        "date_naissance",
        "lieu_naissance",
        "dept_naissance",
        "nationalite",
        "statut",
        "boursier",
        "photo_filename",
        "code_nip",
        "code_ine",
        "scodoc7_id",
        "email",
        "emailperso",
        "domicile",
        "codepostaldomicile",
        "villedomicile",
        "paysdomicile",
        "telephone",
        "telephonemobile",
        "fax",
        "typeadresse",
        "description",
        "group_id",
        "etat",
        "civilite_str",
        "nom_disp",
        "nomprenom",
        "ne",
        "email_default",
    ]

    r = requests.get(
        API_URL + "/partitions/groups/1",
        headers=api_headers,
        verify=CHECK_CERTIFICATE,
    )

    etu = r.json()[0]

    fields_ok = verify_fields(etu, fields)

    assert r.status_code == 200
    assert len(r.json()) == 16
    assert fields_ok is True
    # r = requests.get(
    #     API_URL + "/partitions/groups/1/etat/<string:etat>",
    #     headers=api_headers,
    #     verify=CHECK_CERTIFICATE,
    # )
    # assert r.status_code == 200


# # set_groups
# def test_set_groups(api_headers):
#     """
#     Test 'set_groups'
#
#     Routes :
#         - /partitions/set_groups/partition/<int:partition_id>/groups/<string:groups_id>/delete/<string:groups_to_delete>"
#           "/create/<string:groups_to_create>
#     """
#     r = requests.get(
#         SCODOC_URL
#         + "/partitions/set_groups/partition/<int:partition_id>/groups/<string:groups_id>"
#           "/delete/<string:groups_to_delete>/create/<string:groups_to_create>",
#         headers=api_headers,
#         verify=CHECK_CERTIFICATE,
#     )
#     assert r.status_code == 200
